@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2017 Zabbix SIA
+** Copyright (C) 2001-2018 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -109,6 +109,9 @@ foreach ($data['data']['problems'] as $eventid => $problem) {
 		? zbx_date2str(TIME_FORMAT_SECONDS, $problem['clock'])
 		: zbx_date2str(DATE_TIME_FORMAT_SECONDS, $problem['clock']);
 	$cell_clock = new CCol(new CLink($cell_clock, $url_details));
+
+	$is_acknowledged = $data['config']['event_ack_enable'] && (bool) $problem['acknowledges'];
+
 	if ($show_recovery_data) {
 		if ($problem['r_eventid'] != 0) {
 			$cell_r_clock = ($problem['r_clock'] >= $today)
@@ -125,9 +128,7 @@ foreach ($data['data']['problems'] as $eventid => $problem) {
 		$cell_status = new CSpan($value_str);
 
 		// Add colors and blinking to span depending on configuration and trigger parameters.
-		addTriggerValueStyle($cell_status, $value, $value_clock,
-			$data['config']['event_ack_enable'] && (bool) $problem['acknowledges']
-		);
+		addTriggerValueStyle($cell_status, $value, $value_clock, $is_acknowledged);
 	}
 
 	// Info.
@@ -164,7 +165,7 @@ foreach ($data['data']['problems'] as $eventid => $problem) {
 	]))
 		->addClass($description_style);
 
-	if (!$show_recovery_data) {
+	if (!$show_recovery_data && $data['config'][$is_acknowledged ? 'problem_ack_style' : 'problem_unack_style']) {
 		// blinking
 		$duration = time() - $problem['clock'];
 
@@ -177,7 +178,7 @@ foreach ($data['data']['problems'] as $eventid => $problem) {
 
 	if ($show_timeline) {
 		if ($last_clock != 0) {
-			CScreenProblem::addTimelineBreakpoint($table, $last_clock, $problem['clock'], ZBX_SORT_DOWN);
+			CScreenProblem::addTimelineBreakpoint($table, $last_clock, $problem['clock'], $data['sortorder']);
 		}
 		$last_clock = $problem['clock'];
 
