@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2017 Zabbix SIA
+** Copyright (C) 2001-2018 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -947,8 +947,8 @@ class CHelpItems {
 					'description' => _('Returns information associated with Zabbix Java gateway. Valid params are: ping, version.')
 				],
 				[
-					'key' => 'zabbix[process,<type>,<num>,<state>]',
-					'description' => _('Time a particular Zabbix process or a group of processes (identified by <type> and <num>) spent in <state> in percentage.')
+					'key' => 'zabbix[process,<type>,<mode>,<state>]',
+					'description' => _('Time a particular Zabbix process or a group of processes (identified by <type> and <mode>) spent in <state> in percentage.')
 				],
 				[
 					'key' => 'zabbix[proxy,<name>,<param>]',
