@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2017 Zabbix SIA
+** Copyright (C) 2001-2018 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -50,7 +50,7 @@ var timeControl = {
 				mainObject: 0, // object on changing will reflect on all others
 				onDashboard: 0, // object is on dashboard
 				sliderMaximumTimePeriod: null, // max period in seconds
-				profile: { // if values are not null, will save fixedperiod state here, on change
+				profile: { // if values are not null, will save timeline and fixedperiod state here, on change
 					idx: null,
 					idx2: null
 				}
@@ -62,7 +62,7 @@ var timeControl = {
 				}
 			}
 
-			if (isset('isNow', time) && time.isNow === '0') {
+			if (isset('isNow', time) && time.isNow == 0) {
 				time.isNow = false;
 			}
 			this.objectList[id].time = time;
@@ -118,7 +118,7 @@ var timeControl = {
 					? obj.time.endtime - 3 * ((obj.time.period < 86400) ? 86400 : obj.time.period)
 					: nowDate.setZBXDate(obj.time.starttime) / 1000;
 
-				obj.time.usertime = (!isset('usertime', obj.time))
+				obj.time.usertime = (!isset('usertime', obj.time) || obj.time.isNow)
 					? obj.time.endtime
 					: nowDate.setZBXDate(obj.time.usertime) / 1000;
 
@@ -232,12 +232,14 @@ var timeControl = {
 	refreshImage: function(id) {
 		var obj = this.objectList[id],
 			period = this.timeline.period(),
-			stime = new CDate((this.timeline.usertime() - this.timeline.period()) * 1000).getZBXDate();
+			stime = new CDate((this.timeline.usertime() - this.timeline.period()) * 1000).getZBXDate(),
+			isNow = this.timeline.isNow();
 
 		// image
 		var imgUrl = new Curl(obj.src);
 		imgUrl.setArgument('period', period);
 		imgUrl.setArgument('stime', stime);
+		imgUrl.setArgument('isNow', + isNow);
 
 		var img = jQuery('<img />', {id: id + '_tmp'})
 			.on('load', function() {
@@ -280,6 +282,7 @@ var timeControl = {
 		graphUrl.setArgument('width', obj.objDims.width);
 		graphUrl.setArgument('period', period);
 		graphUrl.setArgument('stime', stime);
+		graphUrl.setArgument('isNow', + isNow);
 
 		jQuery('#' + obj.containerid).attr('href', graphUrl.getUrl());
 	},
@@ -298,19 +301,28 @@ var timeControl = {
 		}
 
 		var widget = widgets[0],
-			url = new Curl('zabbix.php');
+			url = new Curl('zabbix.php'),
+			post_args = {
+				uniqueid: widget['uniqueid'],
+				only_footer: 1
+			};
+
+		if (widget.type === 'graph') {
+			post_args.period = this.timeline.period();
+		}
 
 		url.setArgument('action', 'widget.graph.view');
 		jQuery.ajax({
 			url: url.getUrl(),
 			method: 'POST',
-			data: {
-				uniqueid: widget['uniqueid'],
-				only_footer: 1
-			},
+			data: post_args,
 			dataType: 'json',
 			success: function(resp) {
 				widget['content_footer'].html(resp.footer);
+
+				if ('period_string' in resp) {
+					jQuery('h4 span', widget['content_header']).text(resp.period_string);
+				}
 			}
 		});
 	},
@@ -358,7 +370,8 @@ var timeControl = {
 
 	objectUpdate: function() {
 		var usertime = this.timeline.usertime(),
-			period = this.timeline.period();
+			period = this.timeline.period(),
+			isNow = (this.timeline.now() || this.timeline.isNow());
 
 		// secure browser from fast user operations
 		if (isNaN(usertime) || isNaN(period)) {
@@ -371,16 +384,14 @@ var timeControl = {
 			return;
 		}
 
-		if (this.timeline.now() || this.timeline.isNow()) {
-			usertime += 31536000; // 31536000 = 86400 * 365 = 1 year
-		}
-
-		var date = new CDate((usertime - period) * 1000);
+		var date = new CDate((usertime - period) * 1000),
+			stime = date.getZBXDate();
 
 		if (this.refreshPage) {
 			var url = new Curl(location.href);
 			url.setArgument('period', period);
-			url.setArgument('stime', date.getZBXDate());
+			url.setArgument('stime', stime);
+			url.setArgument('isNow', + isNow);
 			url.unsetArgument('output');
 
 			location.href = url.getUrl();
@@ -394,7 +405,20 @@ var timeControl = {
 			this.scrollbar.setBarPosition();
 			this.scrollbar.setGhostByBar();
 
-			flickerfreeScreen.refreshAll(period, date.getZBXDate(), this.timeline.isNow());
+			var url = new Curl('zabbix.php');
+			url.setArgument('action', 'timeline.update');
+
+			sendAjaxData(url.getUrl(), {
+				data: {
+					idx: this.scrollbar.profile.idx,
+					idx2: this.scrollbar.profile.idx2,
+					period: period,
+					stime: stime,
+					isNow: + isNow
+				}
+			});
+
+			flickerfreeScreen.refreshAll(period, stime, isNow);
 		}
 	},
 
@@ -455,6 +479,7 @@ var CTimeLine = Class.create({
 	_isNow:		false,	// state if time is set to NOW (for outside usage)
 	minperiod:	60,		// minimal allowed period
 	maxperiod:	null,	// max period in seconds
+	is_selectall_period: false, // Will be set to true if period 'All' is selected.
 
 	initialize: function(period, starttime, usertime, endtime, maximumPeriod, isNow) {
 		if ((endtime - starttime) < (3 * this.minperiod)) {
@@ -492,17 +517,29 @@ var CTimeLine = Class.create({
 		this._endtime = end;
 		this._usertime = end;
 		this._now = true;
+
+		if (this.is_selectall_period && this._isNow) {
+			this._period = Math.min(this._endtime - this._starttime, this.maxperiod);
+			this._usertime = this._endtime;
+		}
 	},
 
 	refreshEndtime: function() {
 		this._endtime = parseInt(new CDate().getTime() / 1000);
+
+		if (this.is_selectall_period && this._isNow) {
+			this._period = Math.min(this._endtime - this._starttime, this.maxperiod);
+			this._usertime = this._endtime;
+		}
 	},
 
 	period: function(period) {
 		if (empty(period)) {
-			return this._period;
+			return this.is_selectall_period ? this.maxperiod : this._period;
 		}
 
+		this.is_selectall_period = (period == this.maxperiod);
+
 		if ((this._usertime - period) < this._starttime) {
 			period = this._usertime - this._starttime;
 		}
@@ -688,7 +725,7 @@ var CScrollBar = Class.create({
 	},
 
 	navigateLeft: function(e, left) {
-		if (this.disabled) {
+		if (this.disabled || timeControl.timeline.is_selectall_period) {
 			return false;
 		}
 
@@ -725,7 +762,7 @@ var CScrollBar = Class.create({
 	},
 
 	navigateRight: function(e, right) {
-		if (this.disabled) {
+		if (this.disabled || timeControl.timeline.is_selectall_period) {
 			return false;
 		}
 
@@ -1087,25 +1124,17 @@ var CScrollBar = Class.create({
 
 		this.fixedperiod = (this.fixedperiod == 1) ? 0 : 1;
 
-		var url = location.href,
-			ajax_data = {
-				favobj: 'timelinefixedperiod',
-				favid: this.fixedperiod
-			};
-
-		// If we know profile entry, that should be updated, update it directly
-		if (isset('idx', this.profile) && !is_null(this.profile.idx)) {
-			var url = new Curl('zabbix.php');
-			url.setArgument('action', 'profile.update');
-			url = url.getUrl();
-
+		var url = new Curl('zabbix.php'),
 			ajax_data = {
 				idx: this.profile.idx + '.timelinefixed',
 				value_int: this.fixedperiod
 			};
-			if (isset('idx2', this.profile) && !is_null(this.profile.idx2)) {
-				ajax_data.idx2 = [this.profile.idx2];
-			}
+
+		url.setArgument('action', 'profile.update');
+		url = url.getUrl();
+
+		if (isset('idx2', this.profile) && !is_null(this.profile.idx2)) {
+			ajax_data.idx2 = [this.profile.idx2];
 		}
 
 		// sending fixed/dynamic setting to server to save in a profile
