@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2017 Zabbix SIA
+** Copyright (C) 2001-2018 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -113,6 +113,16 @@ if (!hasRequest('filter_rst')) {
 	$_REQUEST['filter_timetill'] = getRequest('filter_timetill',
 		CProfile::get('web.avail_report.'.$availabilityReportMode.'.timetill', 0)
 	);
+
+	if ($availabilityReportMode == AVAILABILITY_REPORT_BY_TEMPLATE) {
+		$_REQUEST['tpl_triggerid'] = getRequest('tpl_triggerid',
+			CProfile::get('web.avail_report.'.$availabilityReportMode.'.tpl_triggerid', 0)
+		);
+
+		$_REQUEST['hostgroupid'] = getRequest('hostgroupid',
+			CProfile::get('web.avail_report.'.$availabilityReportMode.'.hostgroupid', 0)
+		);
+	}
 }
 
 CProfile::update('web.avail_report.'.$availabilityReportMode.'.groupid', getRequest('filter_groupid', 0),
@@ -128,6 +138,16 @@ CProfile::update('web.avail_report.'.$availabilityReportMode.'.hostid', getReque
 	PROFILE_TYPE_ID
 );
 
+if ($availabilityReportMode == AVAILABILITY_REPORT_BY_TEMPLATE) {
+	CProfile::update('web.avail_report.'.$availabilityReportMode.'.tpl_triggerid', getRequest('tpl_triggerid', 0),
+		PROFILE_TYPE_ID
+	);
+
+	CProfile::update('web.avail_report.'.$availabilityReportMode.'.hostgroupid', getRequest('hostgroupid', 0),
+		PROFILE_TYPE_ID
+	);
+}
+
 $config = select_config();
 
 if ($_REQUEST['filter_timetill'] > 0 && $_REQUEST['filter_timesince'] > $_REQUEST['filter_timetill']) {
@@ -233,34 +253,7 @@ elseif (isset($_REQUEST['filter_hostid'])) {
 			'with_triggers' => true,
 			'preservekeys' => true
 		]);
-
-		$parents = [];
-		$parent_name = '';
-		foreach ($groups as $group) {
-			$parent = explode('/', $group['name']);
-			if (count($parent) > 1) {
-				array_pop($parent);
-				foreach ($parent as $sub_parent) {
-					if ($parent_name === '') {
-						$parent_name = $sub_parent;
-					}
-					else {
-						$parent_name .= '/'.$sub_parent;
-					}
-					$parents[] = $parent_name;
-				}
-			}
-		}
-
-		if ($parents) {
-			$parent_groups = API::HostGroup()->get([
-				'output' => ['groupid', 'name'],
-				'filter' => ['name' => $parents],
-				'preservekeys' => true
-			]);
-
-			$groups = array_replace($groups, $parent_groups);
-		}
+		$groups = CPageFilter::enrichParentGroups($groups);
 
 		order_result($groups, 'name');
 
@@ -344,34 +337,7 @@ elseif (isset($_REQUEST['filter_hostid'])) {
 			'monitored_hosts' => true,
 			'preservekeys' => true
 		]);
-
-		$parents = [];
-		$parent_name = '';
-		foreach ($groups as $group) {
-			$parent = explode('/', $group['name']);
-			if (count($parent) > 1) {
-				array_pop($parent);
-				foreach ($parent as $sub_parent) {
-					if ($parent_name === '') {
-						$parent_name = $sub_parent;
-					}
-					else {
-						$parent_name .= '/'.$sub_parent;
-					}
-					$parents[] = $parent_name;
-				}
-			}
-		}
-
-		if ($parents) {
-			$parent_groups = API::HostGroup()->get([
-				'output' => ['groupid', 'name'],
-				'filter' => ['name' => $parents],
-				'preservekeys' => true
-			]);
-
-			$groups = array_replace($groups, $parent_groups);
-		}
+		$groups = CPageFilter::enrichParentGroups($groups);
 
 		order_result($groups, 'name');
 
@@ -414,34 +380,7 @@ elseif (isset($_REQUEST['filter_hostid'])) {
 			'with_triggers' => true,
 			'preservekeys' => true
 		]);
-
-		$parents = [];
-		$parent_name = '';
-		foreach ($groups as $group) {
-			$parent = explode('/', $group['name']);
-			if (count($parent) > 1) {
-				array_pop($parent);
-				foreach ($parent as $sub_parent) {
-					if ($parent_name === '') {
-						$parent_name = $sub_parent;
-					}
-					else {
-						$parent_name .= '/'.$sub_parent;
-					}
-					$parents[] = $parent_name;
-				}
-			}
-		}
-
-		if ($parents) {
-			$parent_groups = API::HostGroup()->get([
-				'output' => ['groupid', 'name'],
-				'filter' => ['name' => $parents],
-				'preservekeys' => true
-			]);
-
-			$groups = array_replace($groups, $parent_groups);
-		}
+		$groups = CPageFilter::enrichParentGroups($groups);
 
 		order_result($groups, 'name');
 
@@ -510,7 +449,17 @@ elseif (isset($_REQUEST['filter_hostid'])) {
 
 	$triggers = API::Trigger()->get($triggerOptions);
 
-	CArrayHelper::sort($triggers, ['host', 'description']);
+	if (getRequest('filter_hostid') == 0 || $availabilityReportMode == AVAILABILITY_REPORT_BY_TEMPLATE) {
+		foreach ($triggers as &$trigger) {
+			$trigger['host_name'] = $trigger['hosts'][0]['name'];
+		}
+		unset($trigger);
+
+		CArrayHelper::sort($triggers, ['host_name', 'description']);
+	}
+	else {
+		CArrayHelper::sort($triggers, ['description']);
+	}
 
 	$paging = getPagingLine($triggers, ZBX_SORT_UP, new CUrl('report2.php'));
 
@@ -521,7 +470,7 @@ elseif (isset($_REQUEST['filter_hostid'])) {
 
 		$triggerTable->addRow([
 			($_REQUEST['filter_hostid'] == 0 || $availabilityReportMode == AVAILABILITY_REPORT_BY_TEMPLATE)
-				? $trigger['hosts'][0]['name'] : null,
+				? $trigger['host_name'] : null,
 			new CLink($trigger['description'],
 				(new CUrl('zabbix.php'))
 					->setArgument('action', 'problem.view')
